@@ -1,7 +1,7 @@
 """
 Type annotations for sso-oidc service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -16,7 +16,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_sso_oidc.type_defs import (
+from .type_defs import (
     CreateTokenResponseTypeDef,
     RegisterClientResponseTypeDef,
     StartDeviceAuthorizationResponseTypeDef,
@@ -51,8 +51,8 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sso-oidc.html#SSOOIDC.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -60,8 +60,8 @@ class SSOOIDCClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def create_token(
@@ -76,8 +76,8 @@ class SSOOIDCClient:
         redirectUri: str = None,
     ) -> CreateTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create-token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3-stubs documentation](./client.md#create-token)
         """
 
     def generate_presigned_url(
@@ -88,22 +88,22 @@ class SSOOIDCClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def register_client(
         self, clientName: str, clientType: str, scopes: List[str] = None
     ) -> RegisterClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register-client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3-stubs documentation](./client.md#register-client)
         """
 
     def start_device_authorization(
         self, clientId: str, clientSecret: str, startUrl: str
     ) -> StartDeviceAuthorizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start-device-authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3-stubs documentation](./client.md#start-device-authorization)
         """
